import React from 'react'
import styled from 'styled-components'
import { th } from '@pubsweet/ui-toolkit'
import { graphql, compose } from 'react-apollo'
import { europepmcUrl } from 'config'
import { H1, H2, Icon, Button } from '@pubsweet/ui'
import {
  SplitPage,
  InfoPanel,
  StepPanel,
  Notification,
  Buttons,
  BoldCheck,
  A,
} from '../ui'
import PubMedSearch, { PreprintSearch } from '../citation-search'
import CreateHeader from './CreateHeader'
import CreateInfo from './CreateInfo'
import { USER_MANUSCRIPTS } from '../dashboard/operations'
import { CREATE_NOTE } from '../operations'
import { CREATE_MANUSCRIPT } from './operations'

const SplitPageShort = styled(SplitPage)`
  min-height: calc(100vh - (${th('gridUnit')} * 20));
`
class CreateSetup extends React.Component {
  state = {
    message: null,
    id: null,
    showInfo: false,
    checked: false,
    cancelCheck: false,
    inEPMC: false,
  }
  manuscriptSetup = async (citationData, component) => {
    if (citationData) {
      const { createNote, createManuscript, history } = component.props
      const { note, ...citation } = citationData
      const created = await createManuscript({
        variables: { data: { ...citation } },
      })
      const { manuscript, errors } = created.data.createManuscript
      const { id, version } = manuscript
      const route = `/submission/${id}/create`
      if (errors && errors.length > 0) {
        const { message } = errors[0]
        component.setState({ message, id })
        setTimeout(() => history.push(route), 3500)
      } else {
        if (note) {
          await createNote({
            variables: {
              data: {
                manuscriptId: id,
                manuscriptVersion: version,
                ...note,
              },
            },
          })
        }
        history.push(route)
      }
    }
  }
  render() {
    const { showInfo, id, message, checked, cancelCheck, inEPMC } = this.state
    const { location, history } = this.props
    const enter = location.search.substr(1)
    const preprint = enter === 'preprint'
    return (
      <SplitPageShort>
        <StepPanel>
          {!enter ? (
            <div>
              <H1 style={{ textAlign: 'center' }}>Submit a new manuscript</H1>
              <H2>Criteria for submission</H2>
              <p>
                {`Manuscripts submitted to Europe PMC plus must be peer-reviewed, accepted for publication, and derive from research supported, in whole or in part, by one or more `}
                <A href={`${europepmcUrl}/Funders/`}>Europe PMC funders</A>.
              </p>
              <BoldCheck
                checked={checked}
                label="I accept these requirements."
                onChange={e => this.setState({ checked: e.target.checked })}
              />
              <Buttons right style={{ marginTop: '100px' }}>
                <Button
                  disabled={!checked}
                  onClick={() => history.push({ search: '?manuscript' })}
                  primary
                >
                  Next
                </Button>
              </Buttons>
            </div>
          ) : (
            <div>
              <CreateHeader currentStep={0} preprint={preprint} />
              {id && (
                <Notification type="warning">
                  {message} Redirecting to {id}.
                </Notification>
              )}
              {!cancelCheck && <H2>Citation information</H2>}
              {preprint ? (
                <PreprintSearch
                  changeNote
                  citationData={d => {
                    d.preprint = true
                    this.manuscriptSetup(d, this)
                  }}
                />
              ) : (
                <PubMedSearch
                  changeInfo={v => this.setState(v)}
                  changeNote
                  citationData={d => this.manuscriptSetup(d, this)}
                />
              )}
            </div>
          )}
        </StepPanel>
        <InfoPanel>
          <div
            className={showInfo ? 'showInfo' : 'hidden'}
            id="more-info"
            onClick={() => this.setState({ showInfo: !showInfo })}
          >
            More Info
            {!showInfo && <Icon>chevron-right</Icon>}
            {showInfo && <Icon>chevron-down</Icon>}
          </div>
          <CreateInfo
            cancelCheck={cancelCheck}
            currentStep={enter ? 0 : -1}
            inEPMC={cancelCheck && inEPMC}
            preprint={preprint}
          />
        </InfoPanel>
      </SplitPageShort>
    )
  }
}

export default compose(
  graphql(CREATE_MANUSCRIPT, {
    name: 'createManuscript',
    options: { refetchQueries: [{ query: USER_MANUSCRIPTS }] },
  }),
  graphql(CREATE_NOTE, { name: 'createNote' }),
)(CreateSetup)
