const logger = require('@pubsweet/logger')
const { checkJobStatus } = require('../job-runner')
const Manuscript = require('../xpub-model/entities/manuscript/data-access')
const { addCitation } = require('../xml-validation')

if (!process.env.ENABLE_CRONJOB_ADDCITATIONCHECK) {
  logger.info(
    'ENABLE_CRONJOB_ADDCITATIONCHECK not defined. citationCheck cronjob exits.',
  )
  process.exit(0)
}

;(async () => {
  await checkJobStatus('check-citation-xml', async () => {
    const updateTime = Date.now()
    logger.info(`Running manuscripts check to add manuscript citation XML`)
    await citationCheck()
    logger.info(
      `Manuscript citation XML check was finished in ${Date.now() -
        updateTime} ms`,
    )
  })
  await Manuscript.knex().destroy()
  process.exit(0)
})()

process
  .on('uncaughtException', async (err, origin) => {
    logger.error('Uncaught Exception thrown: ', err)
    logger.error('Exception thrown at: ', origin)
    await Manuscript.knex().destroy()
    process.exit(1)
  })
  .on('unhandledRejection', async (reason, promise) => {
    logger.error('Unhandled Rejection: ', reason)
    logger.error('Rejected at promise: ', promise)
    await Manuscript.knex().destroy()
    process.exit(1)
  })

async function citationCheck() {
  const manuscripts = await Manuscript.query()
    .where('status', 'repo-ready')
    .where('pdf_deposit_state', 'ADDING_CITATION')
    .whereNull('manuscript.deleted')

  if (manuscripts && manuscripts.length > 0) {
    await manuscripts.reduce(async (promise, m) => {
      await promise
      try {
        await addCitation(m.id)
      } catch (e) {
        logger.error(e.message)
      }
      return Promise.resolve()
    }, Promise.resolve())
  }
  logger.info('No citations need to be added to XML.')
  return true
}
